@@ -1,20 +1,21 @@
 package Class::Meta::Express;
 
-# $Id: Express.pm 2888 2006-05-30 03:20:16Z theory $
+# $Id: Express.pm 2974 2006-07-04 22:33:35Z theory $
 
 use strict;
 use vars qw($VERSION);
 use Class::Meta;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 my %meta_for;
 
 sub import {
+    my $pkg = shift;
     my $caller = caller;
     no strict 'refs';
     return shift if defined &{"$caller\::meta"};
-    *{"$caller\::$_"} = \&{$_} for qw(meta ctor has method build);
+    *{"$caller\::$_"} = $pkg->can($_) for qw(meta ctor has method build);
     return shift;
 }
 
@@ -326,7 +327,7 @@ created with C<has> that don't specify their own data types.
 Installs an C<import()> method into the calling name space that exports the
 express functions. The trick is that, if you've specified values for the
 C<meta_class> and/or C<default_type> parameters, they will be used in the
-C<meta> function exported by your class! Foe example:
+C<meta> function exported by your class! For example:
 
   package My::Base;
   use Class::Meta::Express;
@@ -463,6 +464,38 @@ Removes the C<meta>, C<ctor>, C<has>, C<method>, and C<build> functions from
 the calling name space, and then calls C<build()> on the Class::Meta object
 created by C<meta>.
 
+=head1 Overriding Functions
+
+It is possible to override the functions exported by this module by
+subclassing it (after a fashion). Say that you wanted to change the C<meta()>
+function so that it forces all attributes to default to a the type "string".
+Just override the function like so:
+
+  package My::Express;
+  use base 'Class::Meta::Express';
+
+  sub meta {
+      splice @_, 1, 2, default_type => 'string';
+      goto &Class::Meta::Express::meta;
+  }
+
+The trick here is to set C<@_> and then C<goto &Class::Meta::Express::meta>.
+This is so that the package that calls this function is seen as the caller in
+C<Class:Meta::Express::meta()> and the Class::Meta object properlly created
+for that package.
+
+Why would you want to do all this? Well, perhaps you're building a I<lot> of
+classes and don't want to have to repeat yourself so much. So now all you have
+to do is use your My::Express module instead of Class::Meta::Express:
+
+    package My::Person;
+    use My::Express;
+    meta person => ();
+    has  name   => ();
+    build;
+
+And now you've created a new class with the string type attribute "name".
+
 =head1 See Also
 
 =over
